==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dss-network-plugin/translations/dss-network-plugin_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1개의 새 메시지</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 연결됨</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>유선 연결</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>핫스팟</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>프로토콜</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>보안 유형</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>밴드</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>채널</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>인터페이스</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>넷마스크</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>기본 DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>접두사</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>속도</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>디바이스 사용해제됨</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>연결됨, 인터넷 없음</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>연결되지 않음</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>네트워크 케이블이 연결되어 있지 않습니다.</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>연결 중</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>인증 중</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP 주소 가져오는 중</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>연결됨</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>연결 끊김</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP 충돌</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>실패</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>주소 불러오는 중</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>유선 네트워크</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>유선 네트워크 %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>무선 네트워크</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>무선 네트워크 %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>디바이스 사용해제됨</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>네트워크 케이블이 연결되어 있지 않습니다.</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>연결되지 않음</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>연결 중</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>연결됨, 인터넷 없음</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>연결 실패</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP 충돌</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>유선 연결 사용안함</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>유선 연결 사용가능</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>무선 연결 사용안함</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>무선 연결 사용가능</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>네트워크 사용안함</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>네트워크 사용</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>네트워크 설정</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1개의 새 메시지</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>무선 네트워크</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>유선 네트워크</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 연결됨</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>숨겨진 네트워크에 연결</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>연결</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>명칭(SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>핫스팟</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>프로토콜</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>보안 유형</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>채널</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>밴드</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>인터페이스</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>넷마스크</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>기본 DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>접두사</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>속도</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>디바이스 사용해제됨</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>연결됨, 인터넷 없음</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>연결되지 않음</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>네트워크 케이블이 연결되어 있지 않습니다.</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>연결 중</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>인증 중</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP 주소 가져오는 중</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>연결됨</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>연결 끊김</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP 충돌</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>실패</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>주소 불러오는 중</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>유선 네트워크</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>유선 네트워크 %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>무선 네트워크</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>무선 네트워크 %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>디바이스 사용해제됨</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>네트워크 케이블이 연결되어 있지 않습니다.</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>연결되지 않음</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>연결 중</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>연결됨, 인터넷 없음</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>연결 실패</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP 충돌</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>유선 연결 사용안함</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>유선 연결 사용가능</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>무선 연결 사용안함</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>무선 연결 사용가능</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>네트워크 사용안함</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>네트워크 사용</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>네트워크 설정</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>유선 연결</translation>
    </message>
</context>
</TS>
